@@ -49,7 +49,7 @@ const std::string RDB_SCHEMA_DATE = "2025-04-18";
 
 // Schema for ".avg.fwa" files
 const std::string RDB_SCHEMA_RIEGL_AVG_FWA(
-    "{\"extension\":\"avg.fwa\",\"identifier\":\"avg.fwa\",\"metadata\":[],\"attribute"
+    "{\"identifier\":\"avg.fwa\",\"extension\":\"avg.fwa\",\"metadata\":[],\"attribute"
     "s\":[\"riegl.id*\",\"riegl.amplitude\",\"riegl.gain\",\"riegl.raw_range\",\"rieg"
     "l.wfm_echo_time_offset\",\"riegl.wfm_sbl_id\",\"riegl.deviation?\",\"riegl.p"
     "ulse_width?\"]}"
@@ -57,7 +57,7 @@ const std::string RDB_SCHEMA_RIEGL_AVG_FWA(
 
 // Schema for ".avg.sbx" files
 const std::string RDB_SCHEMA_RIEGL_AVG_SBX(
-    "{\"extension\":\"avg.sbx\",\"identifier\":\"avg.sbx\",\"metadata\":[],\"attribute"
+    "{\"identifier\":\"avg.sbx\",\"extension\":\"avg.sbx\",\"metadata\":[],\"attribute"
     "s\":[\"riegl.id*\",\"riegl.wfm_sbl_channel\",\"riegl.wfm_sbl_mean\",\"riegl.wf"
     "m_sbl_std_dev\",\"riegl.wfm_sbl_time_offset\",\"riegl.wfm_sda_first\",\"rieg"
     "l.wfm_sda_count\"]}"
@@ -65,7 +65,7 @@ const std::string RDB_SCHEMA_RIEGL_AVG_SBX(
 
 // Schema for ".avg.sidx" files
 const std::string RDB_SCHEMA_RIEGL_AVG_SIDX(
-    "{\"extension\":\"avg.sidx\",\"identifier\":\"avg.sidx\",\"metadata\":[\"riegl.sho"
+    "{\"identifier\":\"avg.sidx\",\"extension\":\"avg.sidx\",\"metadata\":[\"riegl.sho"
     "t_info\",\"riegl.waveform_info\",\"riegl.echo_info?\",\"riegl.waveform_avera"
     "ging_settings\"],\"attributes\":[\"riegl.id\",\"riegl.shot_timestamp_hr*\",\"r"
     "iegl.wfm_sbl_first\",\"riegl.wfm_sbl_count\",\"riegl.echo_first?\",\"riegl.e"
@@ -74,13 +74,13 @@ const std::string RDB_SCHEMA_RIEGL_AVG_SIDX(
 
 // Schema for ".avg.sp{C}" files
 const std::string RDB_SCHEMA_RIEGL_AVG_SPC(
-    "{\"extension\":\"avg.sp{C}\",\"identifier\":\"avg.sp{C}\",\"metadata\":[],\"attri"
+    "{\"identifier\":\"avg.sp{C}\",\"extension\":\"avg.sp{C}\",\"metadata\":[],\"attri"
     "butes\":[\"riegl.id*\",\"riegl.wfm_sample_value\"]}"
 );
 
 // Schema for ".bsx" files
 const std::string RDB_SCHEMA_RIEGL_BSX(
-    "{\"extension\":\"bsx\",\"identifier\":\"bsx\",\"metadata\":[\"riegl.time_base\"],\""
+    "{\"identifier\":\"bsx\",\"extension\":\"bsx\",\"metadata\":[\"riegl.time_base\"],\""
     "attributes\":[\"riegl.id\",\"riegl.pof_timestamp*\",\"riegl.accelerometer_bi"
     "as\",\"riegl.accelerometer_scale\",\"riegl.gyroscope_bias\",\"riegl.gyroscop"
     "e_scale\"]}"
@@ -88,7 +88,7 @@ const std::string RDB_SCHEMA_RIEGL_BSX(
 
 // Schema for ".cpx" files
 const std::string RDB_SCHEMA_RIEGL_CPX(
-    "{\"extension\":\"cpx\",\"identifier\":\"cpx\",\"metadata\":[\"riegl.geo_tag\",\"rie"
+    "{\"identifier\":\"cpx\",\"extension\":\"cpx\",\"metadata\":[\"riegl.geo_tag\",\"rie"
     "gl.control_object_catalog\",\"riegl.item_names\",\"riegl.imported_files\"],"
     "\"attributes\":[\"riegl.id\",\"riegl.xyz*\",\"riegl.xyz_accuracies\",\"riegl.co"
     "ntrol_object_type\",\"riegl.zenith_vector\",\"riegl.used_for_adjustment\",\""
@@ -100,7 +100,7 @@ const std::string RDB_SCHEMA_RIEGL_CPX(
 
 // Schema for ".cyl" files
 const std::string RDB_SCHEMA_RIEGL_CYL(
-    "{\"extension\":\"cyl\",\"identifier\":\"cyl\",\"metadata\":[\"riegl.geo_tag\"],\"at"
+    "{\"identifier\":\"cyl\",\"extension\":\"cyl\",\"metadata\":[\"riegl.geo_tag\"],\"at"
     "tributes\":[\"riegl.id\",\"riegl.xyz*\",\"riegl.cylinder_axis_direction\",\"ri"
     "egl.cylinder_radius\",\"riegl.cylinder_height\",\"riegl.cylinder_radius_co"
     "nfidence\",\"riegl.cylinder_direction_confidence\",\"riegl.std_dev\"]}"
@@ -108,21 +108,21 @@ const std::string RDB_SCHEMA_RIEGL_CYL(
 
 // Schema for ".dmix" files
 const std::string RDB_SCHEMA_RIEGL_DMIX(
-    "{\"extension\":\"dmix\",\"identifier\":\"dmix\",\"metadata\":[\"riegl.device?\",\"r"
+    "{\"identifier\":\"dmix\",\"extension\":\"dmix\",\"metadata\":[\"riegl.device?\",\"r"
     "iegl.dmi_config\",\"riegl.time_base\"],\"attributes\":[\"riegl.id\",\"riegl.dm"
     "i_count\",\"riegl.dmi_path_length_raw\",\"riegl.pof_timestamp*\"]}"
 );
 
 // Schema for ".doix" files
 const std::string RDB_SCHEMA_RIEGL_DOIX(
-    "{\"extension\":\"doix\",\"identifier\":\"doix\",\"metadata\":[],\"attributes\":[\"r"
+    "{\"identifier\":\"doix\",\"extension\":\"doix\",\"metadata\":[],\"attributes\":[\"r"
     "iegl.id\",\"riegl.shot_origin\",\"riegl.shot_direction*\",\"riegl.scan_line_"
     "index\",\"riegl.shot_index_line\"]}"
 );
 
 // Schema for ".eifx" files
 const std::string RDB_SCHEMA_RIEGL_EIFX(
-    "{\"extension\":\"eifx\",\"identifier\":\"eifx\",\"metadata\":[\"riegl.device?\",\"r"
+    "{\"identifier\":\"eifx\",\"extension\":\"eifx\",\"metadata\":[\"riegl.device?\",\"r"
     "iegl.time_base\",\"riegl.ttip_configuration?\"],\"attributes\":[\"riegl.id\","
     "\"riegl.event_timestamp*\",\"riegl.event_index?\",\"riegl.event_pulse_width"
     "?\",\"riegl.event_fake_pulse?\",\"riegl.raw_line_angle?\",\"riegl.raw_frame_"
@@ -131,7 +131,7 @@ const std::string RDB_SCHEMA_RIEGL_EIFX(
 
 // Schema for ".epfx" files
 const std::string RDB_SCHEMA_RIEGL_EPFX(
-    "{\"extension\":\"epfx\",\"identifier\":\"epfx\",\"metadata\":[\"riegl.device?\",\"r"
+    "{\"identifier\":\"epfx\",\"extension\":\"epfx\",\"metadata\":[\"riegl.device?\",\"r"
     "iegl.geo_tag\",\"riegl.time_base\",\"riegl.ttip_configuration?\"],\"attribut"
     "es\":[\"riegl.id\",\"riegl.event_timestamp*\",\"riegl.event_index?\",\"riegl.e"
     "vent_pulse_width?\",\"riegl.event_fake_pulse?\",\"riegl.raw_line_angle?\",\""
@@ -141,7 +141,7 @@ const std::string RDB_SCHEMA_RIEGL_EPFX(
 
 // Schema for ".fwa" files
 const std::string RDB_SCHEMA_RIEGL_FWA(
-    "{\"extension\":\"fwa\",\"identifier\":\"fwa\",\"metadata\":[],\"attributes\":[\"rie"
+    "{\"identifier\":\"fwa\",\"extension\":\"fwa\",\"metadata\":[],\"attributes\":[\"rie"
     "gl.id*\",\"riegl.amplitude\",\"riegl.gain\",\"riegl.raw_range\",\"riegl.wfm_ec"
     "ho_time_offset\",\"riegl.wfm_sbl_id\",\"riegl.deviation?\",\"riegl.pulse_wid"
     "th?\",\"riegl.extinction?\",\"riegl.svb_amplitude_volumetric?\",\"riegl.svb_"
@@ -152,7 +152,7 @@ const std::string RDB_SCHEMA_RIEGL_FWA(
 
 // Schema for ".imux" files
 const std::string RDB_SCHEMA_RIEGL_IMUX(
-    "{\"extension\":\"imux\",\"identifier\":\"imux\",\"metadata\":[\"riegl.device\",\"ri"
+    "{\"identifier\":\"imux\",\"extension\":\"imux\",\"metadata\":[\"riegl.device\",\"ri"
     "egl.time_base\",\"riegl.riloc_sensor_information\",\"riegl.rxp_json_parame"
     "ter_1\"],\"attributes\":[\"riegl.id\",\"riegl.timestamp*\",\"riegl.temperature"
     "\",\"riegl.accelerometer\",\"riegl.gyroscope\",\"riegl.accelerometer_raw\",\"r"
@@ -163,7 +163,7 @@ const std::string RDB_SCHEMA_RIEGL_IMUX(
 
 // Schema for ".llhx" files
 const std::string RDB_SCHEMA_RIEGL_LLHX(
-    "{\"extension\":\"llhx\",\"identifier\":\"llhx\",\"metadata\":[\"riegl.device?\",\"r"
+    "{\"identifier\":\"llhx\",\"extension\":\"llhx\",\"metadata\":[\"riegl.device?\",\"r"
     "iegl.geo_tag\",\"riegl.time_base\"],\"attributes\":[\"riegl.pof_latitude\",\"r"
     "iegl.pof_longitude\",\"riegl.pof_height\",\"riegl.pof_timestamp*\",\"riegl.p"
     "of_accuracy_north\",\"riegl.pof_accuracy_east\",\"riegl.pof_accuracy_down\""
@@ -174,7 +174,7 @@ const std::string RDB_SCHEMA_RIEGL_LLHX(
 
 // Schema for ".llhx" files
 const std::string RDB_SCHEMA_RIEGL_TRAJECTORY_LLHX(
-    "{\"extension\":\"llhx\",\"identifier\":\"trajectory.llhx\",\"metadata\":[\"riegl."
+    "{\"identifier\":\"trajectory.llhx\",\"extension\":\"llhx\",\"metadata\":[\"riegl."
     "device?\",\"riegl.geo_tag\",\"riegl.time_base\"],\"attributes\":[\"riegl.id\",\""
     "riegl.pof_timestamp*\",\"riegl.pof_latitude\",\"riegl.pof_longitude\",\"rieg"
     "l.pof_height\",\"riegl.pof_accuracy_north\",\"riegl.pof_accuracy_east\",\"ri"
@@ -191,7 +191,7 @@ const std::string RDB_SCHEMA_RIEGL_TRAJECTORY_LLHX(
 
 // Schema for ".mpx" files
 const std::string RDB_SCHEMA_RIEGL_MPX(
-    "{\"extension\":\"mpx\",\"identifier\":\"mpx\",\"metadata\":[\"riegl.geo_tag\",\"rie"
+    "{\"identifier\":\"mpx\",\"extension\":\"mpx\",\"metadata\":[\"riegl.geo_tag\",\"rie"
     "gl.pixel_info\",\"riegl.time_base?\"],\"attributes\":[\"riegl.id\",\"riegl.xy_"
     "map*\",\"riegl.amplitude\",\"riegl.reflectance\",\"riegl.deviation\",\"riegl.t"
     "imestamp_min?\",\"riegl.timestamp_max?\",\"riegl.point_count\",\"riegl.point"
@@ -203,7 +203,7 @@ const std::string RDB_SCHEMA_RIEGL_MPX(
 
 // Schema for ".mtch" files
 const std::string RDB_SCHEMA_RIEGL_MTCH(
-    "{\"extension\":\"mtch\",\"identifier\":\"mtch\",\"metadata\":[\"riegl.plane_patch"
+    "{\"identifier\":\"mtch\",\"extension\":\"mtch\",\"metadata\":[\"riegl.plane_patch"
     "_matching\"],\"attributes\":[\"riegl.xyz*\",\"riegl.plane_references\",\"riegl"
     ".plane_patch_distance\",\"riegl.plane_patch_lateral_distance\",\"riegl.pla"
     "ne_patch_link_vector\",\"riegl.id\"]}"
@@ -211,7 +211,7 @@ const std::string RDB_SCHEMA_RIEGL_MTCH(
 
 // Schema for ".mvx" files
 const std::string RDB_SCHEMA_RIEGL_MVX(
-    "{\"extension\":\"mvx\",\"identifier\":\"mvx\",\"metadata\":[\"riegl.geo_tag\",\"rie"
+    "{\"identifier\":\"mvx\",\"extension\":\"mvx\",\"metadata\":[\"riegl.geo_tag\",\"rie"
     "gl.time_base?\",\"riegl.voxel_info\"],\"attributes\":[\"riegl.id\",\"riegl.xyz"
     "_map*\",\"riegl.amplitude\",\"riegl.reflectance\",\"riegl.deviation\",\"riegl."
     "timestamp_min?\",\"riegl.timestamp_max?\",\"riegl.point_count\",\"riegl.shap"
@@ -221,7 +221,7 @@ const std::string RDB_SCHEMA_RIEGL_MVX(
 
 // Schema for ".obsx" files
 const std::string RDB_SCHEMA_RIEGL_OBSX(
-    "{\"extension\":\"obsx\",\"identifier\":\"obsx\",\"metadata\":[\"riegl.geo_tag\",\"r"
+    "{\"identifier\":\"obsx\",\"extension\":\"obsx\",\"metadata\":[\"riegl.geo_tag\",\"r"
     "iegl.plane_slope_class_info?\",\"riegl.pointcloud_info\",\"riegl.sda1_sour"
     "ce_files\"],\"attributes\":[\"riegl.xyz\",\"riegl.surface_normal\",\"riegl.pla"
     "ne_slope_class?\",\"riegl.id*\",\"riegl.sda1_plane_patch_one\",\"riegl.sda1_"
@@ -231,7 +231,7 @@ const std::string RDB_SCHEMA_RIEGL_OBSX(
 
 // Schema for ".ocyl" files
 const std::string RDB_SCHEMA_RIEGL_OCYL(
-    "{\"extension\":\"ocyl\",\"identifier\":\"ocyl\",\"metadata\":[\"riegl.device\",\"ri"
+    "{\"identifier\":\"ocyl\",\"extension\":\"ocyl\",\"metadata\":[\"riegl.device\",\"ri"
     "egl.device_geometry\",\"riegl.geo_tag\",\"riegl.georeferencing_parameters\""
     ",\"riegl.scan_pattern?\",\"riegl.time_base\"],\"attributes\":[\"riegl.id\",\"ri"
     "egl.xyz*\",\"riegl.cylinder_axis_direction\",\"riegl.cylinder_radius\",\"rie"
@@ -243,7 +243,7 @@ const std::string RDB_SCHEMA_RIEGL_OCYL(
 
 // Schema for ".opefx" files
 const std::string RDB_SCHEMA_RIEGL_OPEFX(
-    "{\"extension\":\"opefx\",\"identifier\":\"opefx\",\"metadata\":[\"riegl.device\",\""
+    "{\"identifier\":\"opefx\",\"extension\":\"opefx\",\"metadata\":[\"riegl.device\",\""
     "riegl.device_geometry\",\"riegl.geo_tag\",\"riegl.georeferencing_parameter"
     "s\",\"riegl.scan_pattern?\",\"riegl.time_base\",\"riegl.item_names\",\"riegl.c"
     "ontrol_object_reference_file\"],\"attributes\":[\"riegl.id\",\"riegl.xyz*\",\""
@@ -259,7 +259,7 @@ const std::string RDB_SCHEMA_RIEGL_OPEFX(
 
 // Schema for ".opp" files
 const std::string RDB_SCHEMA_RIEGL_OPP(
-    "{\"extension\":\"opp\",\"identifier\":\"opp\",\"metadata\":[\"riegl.device\",\"rieg"
+    "{\"identifier\":\"opp\",\"extension\":\"opp\",\"metadata\":[\"riegl.device\",\"rieg"
     "l.device_geometry\",\"riegl.geo_tag\",\"riegl.georeferencing_parameters\",\""
     "riegl.scan_pattern?\",\"riegl.time_base\",\"riegl.item_names\",\"riegl.contr"
     "ol_object_reference_file\"],\"attributes\":[\"riegl.id\",\"riegl.xyz*\",\"rieg"
@@ -275,7 +275,7 @@ const std::string RDB_SCHEMA_RIEGL_OPP(
 
 // Schema for ".opx" files
 const std::string RDB_SCHEMA_RIEGL_OPX(
-    "{\"extension\":\"opx\",\"identifier\":\"opx\",\"metadata\":[\"riegl.device\",\"rieg"
+    "{\"identifier\":\"opx\",\"extension\":\"opx\",\"metadata\":[\"riegl.device\",\"rieg"
     "l.device_geometry\",\"riegl.geo_tag\",\"riegl.georeferencing_parameters\",\""
     "riegl.scan_pattern?\",\"riegl.time_base\",\"riegl.control_object_catalog\","
     "\"riegl.item_names\",\"riegl.control_object_reference_file\"],\"attributes\""
@@ -293,14 +293,14 @@ const std::string RDB_SCHEMA_RIEGL_OPX(
 
 // Schema for ".owp" files
 const std::string RDB_SCHEMA_RIEGL_OWP(
-    "{\"extension\":\"owp\",\"identifier\":\"owp\",\"metadata\":[],\"attributes\":[\"rie"
+    "{\"identifier\":\"owp\",\"extension\":\"owp\",\"metadata\":[],\"attributes\":[\"rie"
     "gl.id*\",\"riegl.raw_range\",\"riegl.amplitude\",\"riegl.deviation\",\"riegl.g"
     "ain\"]}"
 );
 
 // Schema for ".pefx" files
 const std::string RDB_SCHEMA_RIEGL_PEFX(
-    "{\"extension\":\"pefx\",\"identifier\":\"pefx\",\"metadata\":[\"riegl.geo_tag\",\"r"
+    "{\"identifier\":\"pefx\",\"extension\":\"pefx\",\"metadata\":[\"riegl.geo_tag\",\"r"
     "iegl.vertex_info\",\"riegl.item_names\",\"riegl.imported_files\"],\"attribut"
     "es\":[\"riegl.id\",\"riegl.xyz*\",\"riegl.xyz_accuracies?\",\"riegl.surface_no"
     "rmal\",\"riegl.plane_up\",\"riegl.std_dev\",\"riegl.plane_confidence_normal\""
@@ -311,7 +311,7 @@ const std::string RDB_SCHEMA_RIEGL_PEFX(
 
 // Schema for ".pofx" files
 const std::string RDB_SCHEMA_RIEGL_PROJECT_POFX(
-    "{\"extension\":\"pofx\",\"identifier\":\"project.pofx\",\"metadata\":[\"riegl.dev"
+    "{\"identifier\":\"project.pofx\",\"extension\":\"pofx\",\"metadata\":[\"riegl.dev"
     "ice?\",\"riegl.geo_tag\",\"riegl.time_base\",\"riegl.trajectory_info\"],\"attr"
     "ibutes\":[\"riegl.id\",\"riegl.pof_timestamp*\",\"riegl.pof_latitude\",\"riegl"
     ".pof_longitude\",\"riegl.pof_height\",\"riegl.pof_roll\",\"riegl.pof_pitch\","
@@ -320,7 +320,7 @@ const std::string RDB_SCHEMA_RIEGL_PROJECT_POFX(
 
 // Schema for ".pofx" files
 const std::string RDB_SCHEMA_RIEGL_SCAN_POFX(
-    "{\"extension\":\"pofx\",\"identifier\":\"scan.pofx\",\"metadata\":[\"riegl.device"
+    "{\"identifier\":\"scan.pofx\",\"extension\":\"pofx\",\"metadata\":[\"riegl.device"
     "?\",\"riegl.time_base\",\"riegl.geo_tag\",\"riegl.trajectory_info\"],\"attribu"
     "tes\":[\"riegl.id\",\"riegl.pof_timestamp*\",\"riegl.pof_latitude\",\"riegl.po"
     "f_longitude\",\"riegl.pof_height\",\"riegl.pof_roll\",\"riegl.pof_pitch\",\"ri"
@@ -330,7 +330,7 @@ const std::string RDB_SCHEMA_RIEGL_SCAN_POFX(
 
 // Schema for ".poqx" files
 const std::string RDB_SCHEMA_RIEGL_PROJECT_POQX(
-    "{\"extension\":\"poqx\",\"identifier\":\"project.poqx\",\"metadata\":[\"riegl.tim"
+    "{\"identifier\":\"project.poqx\",\"extension\":\"poqx\",\"metadata\":[\"riegl.tim"
     "e_base\",\"riegl.trajectory_info\"],\"attributes\":[\"riegl.id\",\"riegl.pof_t"
     "imestamp*\",\"riegl.pof_accuracy_north\",\"riegl.pof_accuracy_east\",\"riegl"
     ".pof_accuracy_down\",\"riegl.pof_accuracy_north_east?\",\"riegl.pof_accura"
@@ -348,7 +348,7 @@ const std::string RDB_SCHEMA_RIEGL_PROJECT_POQX(
 
 // Schema for ".poqx" files
 const std::string RDB_SCHEMA_RIEGL_SCAN_POQX(
-    "{\"extension\":\"poqx\",\"identifier\":\"scan.poqx\",\"metadata\":[\"riegl.time_b"
+    "{\"identifier\":\"scan.poqx\",\"extension\":\"poqx\",\"metadata\":[\"riegl.time_b"
     "ase\",\"riegl.trajectory_info\"],\"attributes\":[\"riegl.id\",\"riegl.pof_time"
     "stamp*\",\"riegl.pof_accuracy_north\",\"riegl.pof_accuracy_east\",\"riegl.po"
     "f_accuracy_down\",\"riegl.pof_accuracy_north_east?\",\"riegl.pof_accuracy_"
@@ -366,14 +366,14 @@ const std::string RDB_SCHEMA_RIEGL_SCAN_POQX(
 
 // Schema for ".ppx" files
 const std::string RDB_SCHEMA_RIEGL_PPX(
-    "{\"extension\":\"ppx\",\"identifier\":\"ppx\",\"metadata\":[\"riegl.device\",\"rieg"
+    "{\"identifier\":\"ppx\",\"extension\":\"ppx\",\"metadata\":[\"riegl.device\",\"rieg"
     "l.time_base\"],\"attributes\":[\"riegl.id\",\"riegl.pps_timestamp_intern*\",\""
     "riegl.pps_timestamp_extern\"]}"
 );
 
 // Schema for ".ptch" files
 const std::string RDB_SCHEMA_RIEGL_PROJECT_PTCH(
-    "{\"extension\":\"ptch\",\"identifier\":\"project.ptch\",\"metadata\":[\"riegl.dev"
+    "{\"identifier\":\"project.ptch\",\"extension\":\"ptch\",\"metadata\":[\"riegl.dev"
     "ice\",\"riegl.geo_tag?\",\"riegl.scan_pattern?\",\"riegl.time_base?\",\"riegl."
     "plane_patch_statistics?\"],\"attributes\":[\"riegl.xyz*\",\"riegl.surface_no"
     "rmal\",\"riegl.plane_up\",\"riegl.reflectance?\",\"riegl.point_count\",\"riegl"
@@ -383,7 +383,7 @@ const std::string RDB_SCHEMA_RIEGL_PROJECT_PTCH(
 
 // Schema for ".ptch" files
 const std::string RDB_SCHEMA_RIEGL_SCAN_PTCH(
-    "{\"extension\":\"ptch\",\"identifier\":\"scan.ptch\",\"metadata\":[\"riegl.device"
+    "{\"identifier\":\"scan.ptch\",\"extension\":\"ptch\",\"metadata\":[\"riegl.device"
     "\",\"riegl.device_geometry\",\"riegl.geo_tag\",\"riegl.georeferencing_parame"
     "ters\",\"riegl.scan_pattern?\",\"riegl.time_base\",\"riegl.plane_patch_stati"
     "stics?\",\"riegl.plane_slope_class_info?\"],\"attributes\":[\"riegl.xyz*\",\"r"
@@ -401,7 +401,7 @@ const std::string RDB_SCHEMA_RIEGL_SCAN_PTCH(
 
 // Schema for ".ptch" files
 const std::string RDB_SCHEMA_RIEGL_SCANPOS_PTCH(
-    "{\"extension\":\"ptch\",\"identifier\":\"scanpos.ptch\",\"metadata\":[\"riegl.dev"
+    "{\"identifier\":\"scanpos.ptch\",\"extension\":\"ptch\",\"metadata\":[\"riegl.dev"
     "ice\",\"riegl.geo_tag?\",\"riegl.scan_pattern?\",\"riegl.time_base?\",\"riegl."
     "plane_patch_statistics?\"],\"attributes\":[\"riegl.xyz*\",\"riegl.surface_no"
     "rmal\",\"riegl.plane_up\",\"riegl.reflectance?\",\"riegl.point_count\",\"riegl"
@@ -411,7 +411,7 @@ const std::string RDB_SCHEMA_RIEGL_SCANPOS_PTCH(
 
 // Schema for ".rdbx" files
 const std::string RDB_SCHEMA_RIEGL_RDBX(
-    "{\"extension\":\"rdbx\",\"identifier\":\"rdbx\",\"metadata\":[\"riegl.atmosphere\""
+    "{\"identifier\":\"rdbx\",\"extension\":\"rdbx\",\"metadata\":[\"riegl.atmosphere\""
     ",\"riegl.beam_geometry\",\"riegl.device_geometry\",\"riegl.device\",\"riegl.g"
     "aussian_decomposition?\",\"riegl.exponential_decomposition?\",\"riegl.geo_"
     "tag\",\"riegl.georeferencing_parameters\",\"riegl.mta_settings?\",\"riegl.ne"
@@ -440,7 +440,7 @@ const std::string RDB_SCHEMA_RIEGL_RDBX(
 
 // Schema for ".rmvx" files
 const std::string RDB_SCHEMA_RIEGL_RMVX(
-    "{\"extension\":\"rmvx\",\"identifier\":\"rmvx\",\"metadata\":[\"riegl.geo_tag\",\"r"
+    "{\"identifier\":\"rmvx\",\"extension\":\"rmvx\",\"metadata\":[\"riegl.geo_tag\",\"r"
     "iegl.voxel_info\",\"riegl.time_base?\"],\"attributes\":[\"riegl.id\",\"riegl.v"
     "oxel_index*\",\"riegl.amplitude\",\"riegl.reflectance\",\"riegl.deviation\",\""
     "riegl.direction_medium\",\"riegl.point_count\",\"riegl.voxel_linear_sums\","
@@ -450,7 +450,7 @@ const std::string RDB_SCHEMA_RIEGL_RMVX(
 
 // Schema for ".rt.llhx" files
 const std::string RDB_SCHEMA_RIEGL_TRAJECTORY_RT_LLHX(
-    "{\"extension\":\"rt.llhx\",\"identifier\":\"trajectory.rt.llhx\",\"metadata\":[\""
+    "{\"identifier\":\"trajectory.rt.llhx\",\"extension\":\"rt.llhx\",\"metadata\":[\""
     "riegl.device?\",\"riegl.geo_tag\",\"riegl.time_base\"],\"attributes\":[\"riegl"
     ".id\",\"riegl.pof_latitude\",\"riegl.pof_longitude\",\"riegl.pof_height\",\"ri"
     "egl.pof_timestamp*\",\"riegl.pof_accuracy_north\",\"riegl.pof_accuracy_eas"
@@ -462,7 +462,7 @@ const std::string RDB_SCHEMA_RIEGL_TRAJECTORY_RT_LLHX(
 
 // Schema for ".s10x" files
 const std::string RDB_SCHEMA_RIEGL_S10X(
-    "{\"extension\":\"s10x\",\"identifier\":\"s10x\",\"metadata\":[\"riegl.time_base\","
+    "{\"identifier\":\"s10x\",\"extension\":\"s10x\",\"metadata\":[\"riegl.time_base\","
     "\"riegl.device?\",\"riegl.pose_sensors\"],\"attributes\":[\"riegl.id\",\"riegl."
     "timestamp*\",\"riegl.frame_angle_coarse\",\"riegl.gyroscope_raw\",\"riegl.ac"
     "celerometer_raw\",\"riegl.magnetic_field_sensor_raw\",\"riegl.gyroscope\",\""
@@ -473,7 +473,7 @@ const std::string RDB_SCHEMA_RIEGL_S10X(
 
 // Schema for ".sbx" files
 const std::string RDB_SCHEMA_RIEGL_SBX(
-    "{\"extension\":\"sbx\",\"identifier\":\"sbx\",\"metadata\":[],\"attributes\":[\"rie"
+    "{\"identifier\":\"sbx\",\"extension\":\"sbx\",\"metadata\":[],\"attributes\":[\"rie"
     "gl.id*\",\"riegl.wfm_sbl_channel\",\"riegl.wfm_sbl_mean\",\"riegl.wfm_sbl_st"
     "d_dev\",\"riegl.wfm_sbl_time_offset\",\"riegl.wfm_sda_first\",\"riegl.wfm_sd"
     "a_count\"]}"
@@ -481,7 +481,7 @@ const std::string RDB_SCHEMA_RIEGL_SBX(
 
 // Schema for ".sdcx" files
 const std::string RDB_SCHEMA_RIEGL_SDCX(
-    "{\"extension\":\"sdcx\",\"identifier\":\"sdcx\",\"metadata\":[\"riegl.atmosphere\""
+    "{\"identifier\":\"sdcx\",\"extension\":\"sdcx\",\"metadata\":[\"riegl.atmosphere\""
     ",\"riegl.beam_geometry\",\"riegl.device_geometry\",\"riegl.device\",\"riegl.g"
     "aussian_decomposition?\",\"riegl.exponential_decomposition?\",\"riegl.mta_"
     "settings?\",\"riegl.near_range_correction?\",\"riegl.noise_estimates?\",\"ri"
@@ -503,14 +503,14 @@ const std::string RDB_SCHEMA_RIEGL_SDCX(
 
 // Schema for ".sidx" files
 const std::string RDB_SCHEMA_RIEGL_SIDX(
-    "{\"extension\":\"sidx\",\"identifier\":\"sidx\",\"metadata\":[\"riegl.shot_info\","
+    "{\"identifier\":\"sidx\",\"extension\":\"sidx\",\"metadata\":[\"riegl.shot_info\","
     "\"riegl.echo_info\"],\"attributes\":[\"riegl.id\",\"riegl.shot_timestamp_hr*\""
     ",\"riegl.echo_first\",\"riegl.echo_count\"]}"
 );
 
 // Schema for ".sodx" files
 const std::string RDB_SCHEMA_RIEGL_SODX(
-    "{\"extension\":\"sodx\",\"identifier\":\"sodx\",\"metadata\":[\"riegl.atmosphere\""
+    "{\"identifier\":\"sodx\",\"extension\":\"sodx\",\"metadata\":[\"riegl.atmosphere\""
     ",\"riegl.device\",\"riegl.device_geometry\",\"riegl.device_output_limits\",\""
     "riegl.beam_geometry\",\"riegl.near_range_correction?\",\"riegl.window_echo"
     "_correction?\",\"riegl.receiver_internals?\",\"riegl.gaussian_decompositio"
@@ -527,19 +527,19 @@ const std::string RDB_SCHEMA_RIEGL_SODX(
 
 // Schema for ".sp{C}" files
 const std::string RDB_SCHEMA_RIEGL_SPC(
-    "{\"extension\":\"sp{C}\",\"identifier\":\"sp{C}\",\"metadata\":[],\"attributes\":["
+    "{\"identifier\":\"sp{C}\",\"extension\":\"sp{C}\",\"metadata\":[],\"attributes\":["
     "\"riegl.id*\",\"riegl.wfm_sample_value\"]}"
 );
 
 // Schema for ".vtx" files
 const std::string RDB_SCHEMA_RIEGL_VTX(
-    "{\"extension\":\"vtx\",\"identifier\":\"vtx\",\"metadata\":[\"riegl.geo_tag\"],\"at"
+    "{\"identifier\":\"vtx\",\"extension\":\"vtx\",\"metadata\":[\"riegl.geo_tag\"],\"at"
     "tributes\":[\"riegl.id*\",\"riegl.xyz\",\"riegl.xyz_accuracies?\"]}"
 );
 
 // Schema for ".vxls" files
 const std::string RDB_SCHEMA_RIEGL_VXLS(
-    "{\"extension\":\"vxls\",\"identifier\":\"vxls\",\"metadata\":[\"riegl.voxel_info\""
+    "{\"identifier\":\"vxls\",\"extension\":\"vxls\",\"metadata\":[\"riegl.voxel_info\""
     ",\"riegl.geo_tag?\"],\"attributes\":[\"riegl.id\",\"riegl.xyz*\",\"riegl.covari"
     "ances\",\"riegl.pca_axis_max\",\"riegl.pca_axis_min\",\"riegl.pca_extents\",\""
     "riegl.point_count\",\"riegl.reflectance\",\"riegl.shape_id\",\"riegl.voxel_c"
@@ -548,7 +548,7 @@ const std::string RDB_SCHEMA_RIEGL_VXLS(
 
 // Schema for ".wdcx" files
 const std::string RDB_SCHEMA_RIEGL_WDCX(
-    "{\"extension\":\"wdcx\",\"identifier\":\"wdcx\",\"metadata\":[\"riegl.atmosphere\""
+    "{\"identifier\":\"wdcx\",\"extension\":\"wdcx\",\"metadata\":[\"riegl.atmosphere\""
     ",\"riegl.beam_geometry\",\"riegl.device_geometry\",\"riegl.device\",\"riegl.g"
     "aussian_decomposition?\",\"riegl.exponential_decomposition?\",\"riegl.geo_"
     "tag\",\"riegl.georeferencing_parameters\",\"riegl.mta_settings?\",\"riegl.ne"
@@ -577,7 +577,7 @@ const std::string RDB_SCHEMA_RIEGL_WDCX(
 
 // Schema for ".wex" files
 const std::string RDB_SCHEMA_RIEGL_WEX(
-    "{\"extension\":\"wex\",\"identifier\":\"wex\",\"metadata\":[\"riegl.device\",\"rieg"
+    "{\"identifier\":\"wex\",\"extension\":\"wex\",\"metadata\":[\"riegl.device\",\"rieg"
     "l.notch_filter\",\"riegl.window_analysis\"],\"attributes\":[\"riegl.id\",\"rie"
     "gl.timestamp*\",\"riegl.wex_filter_valid\",\"riegl.wex_point_count\",\"riegl"
     ".wex_amplitude\",\"riegl.wex_amplitude_std_dev\",\"riegl.wex_amplitude_min"
